package com.sundot.airport.system.mapper;

import java.util.List;

import com.sundot.airport.system.domain.SysLargeScreenLearningGrowthOrganizationalSupportDto;
import com.sundot.airport.system.domain.SysLargeScreenLearningGrowthQueryParamDto;
import com.sundot.airport.system.domain.SysLargeScreenLearningGrowthSqlDto;
import com.sundot.airport.system.domain.SysLearningGrowth;

/**
 * 学习成长Mapper接口
 *
 * @author ruoyi
 * @date 2025-10-22
 */
public interface SysLearningGrowthMapper {
    /**
     * 查询学习成长
     *
     * @param id 学习成长主键
     * @return 学习成长
     */
    public SysLearningGrowth selectSysLearningGrowthById(Long id);

    /**
     * 查询学习成长列表
     *
     * @param sysLearningGrowth 学习成长
     * @return 学习成长集合
     */
    public List<SysLearningGrowth> selectSysLearningGrowthList(SysLearningGrowth sysLearningGrowth);

    /**
     * 新增学习成长
     *
     * @param sysLearningGrowth 学习成长
     * @return 结果
     */
    public int insertSysLearningGrowth(SysLearningGrowth sysLearningGrowth);

    /**
     * 修改学习成长
     *
     * @param sysLearningGrowth 学习成长
     * @return 结果
     */
    public int updateSysLearningGrowth(SysLearningGrowth sysLearningGrowth);

    /**
     * 删除学习成长
     *
     * @param id 学习成长主键
     * @return 结果
     */
    public int deleteSysLearningGrowthById(Long id);

    /**
     * 批量删除学习成长
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysLearningGrowthByIds(Long[] ids);

    /**
     * 查询学习成长列表
     *
     * @param condition 筛选条件
     * @return 学习成长集合
     */
    public List<SysLargeScreenLearningGrowthSqlDto> selectSysLearningGrowthListByCondition(SysLargeScreenLearningGrowthQueryParamDto condition);

    /**
     * 工作画像-组织支撑-培训测试平均分趋势图
     *
     * @param dto 大屏查询参数
     * @return 工作画像-组织支撑-培训测试平均分趋势图
     */
    public List<SysLargeScreenLearningGrowthOrganizationalSupportDto> organizationalSupport(SysLargeScreenLearningGrowthQueryParamDto dto);
}
